## 0.23.0.20240109 (2024-01-09)

Bump libsass to 0.23.* (#11253)

## 0.22.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 0.22.0.1 (2023-11-30)

Use `ConvertibleToInt`/`ConvertibleToFloat` in many third-party stubs (#11022)

Note: this may make the latest version of certain stubs packages incompatible with older versions of mypy and pyright.

## 0.22.0.0 (2023-09-01)

Add stubs for libsass (#10638)

